import type { AgentContext } from '../../../agent';
import type { AgentMessage } from '../../../agent/AgentMessage';
import type { FeatureRegistry } from '../../../agent/FeatureRegistry';
import type { InboundMessageContext } from '../../../agent/models/InboundMessageContext';
import type { DependencyManager } from '../../../plugins';
import type { Query } from '../../../storage/StorageService';
import type { ProblemReportMessage } from '../../problem-reports';
import type { CreateProposalOptions, CredentialProtocolMsgReturnType, DeleteCredentialOptions, AcceptProposalOptions, NegotiateProposalOptions, CreateOfferOptions, NegotiateOfferOptions, CreateRequestOptions, AcceptOfferOptions, AcceptRequestOptions, AcceptCredentialOptions, GetFormatDataReturn, CreateProblemReportOptions } from '../CredentialProtocolOptions';
import type { CredentialFormatService, ExtractCredentialFormats } from '../formats';
import type { CredentialExchangeRecord } from '../repository';
import type { CredentialProtocol } from './CredentialProtocol';
import { CredentialState } from '../models/CredentialState';
/**
 * Base implementation of the CredentialProtocol that can be used as a foundation for implementing
 * the CredentialProtocol interface.
 */
export declare abstract class BaseCredentialProtocol<CFs extends CredentialFormatService[] = CredentialFormatService[]> implements CredentialProtocol<CFs> {
    abstract readonly version: string;
    protected abstract getFormatServiceForRecordType(credentialRecordType: string): CFs[number];
    abstract createProposal(agentContext: AgentContext, options: CreateProposalOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract processProposal(messageContext: InboundMessageContext<AgentMessage>): Promise<CredentialExchangeRecord>;
    abstract acceptProposal(agentContext: AgentContext, options: AcceptProposalOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract negotiateProposal(agentContext: AgentContext, options: NegotiateProposalOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract createOffer(agentContext: AgentContext, options: CreateOfferOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract processOffer(messageContext: InboundMessageContext<AgentMessage>): Promise<CredentialExchangeRecord>;
    abstract acceptOffer(agentContext: AgentContext, options: AcceptOfferOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract negotiateOffer(agentContext: AgentContext, options: NegotiateOfferOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract createRequest(agentContext: AgentContext, options: CreateRequestOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract processRequest(messageContext: InboundMessageContext<AgentMessage>): Promise<CredentialExchangeRecord>;
    abstract acceptRequest(agentContext: AgentContext, options: AcceptRequestOptions<CFs>): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract processCredential(messageContext: InboundMessageContext<AgentMessage>): Promise<CredentialExchangeRecord>;
    abstract acceptCredential(agentContext: AgentContext, options: AcceptCredentialOptions): Promise<CredentialProtocolMsgReturnType<AgentMessage>>;
    abstract processAck(messageContext: InboundMessageContext<AgentMessage>): Promise<CredentialExchangeRecord>;
    abstract createProblemReport(agentContext: AgentContext, options: CreateProblemReportOptions): ProblemReportMessage;
    abstract findProposalMessage(agentContext: AgentContext, credentialExchangeId: string): Promise<AgentMessage | null>;
    abstract findOfferMessage(agentContext: AgentContext, credentialExchangeId: string): Promise<AgentMessage | null>;
    abstract findRequestMessage(agentContext: AgentContext, credentialExchangeId: string): Promise<AgentMessage | null>;
    abstract findCredentialMessage(agentContext: AgentContext, credentialExchangeId: string): Promise<AgentMessage | null>;
    abstract getFormatData(agentContext: AgentContext, credentialExchangeId: string): Promise<GetFormatDataReturn<ExtractCredentialFormats<CFs>>>;
    abstract register(dependencyManager: DependencyManager, featureRegistry: FeatureRegistry): void;
    /**
     * Decline a credential offer
     * @param credentialRecord The credential to be declined
     */
    declineOffer(agentContext: AgentContext, credentialRecord: CredentialExchangeRecord): Promise<CredentialExchangeRecord>;
    /**
     * Process a received credential {@link ProblemReportMessage}.
     *
     * @param messageContext The message context containing a credential problem report message
     * @returns credential record associated with the credential problem report message
     */
    processProblemReport(messageContext: InboundMessageContext<ProblemReportMessage>): Promise<CredentialExchangeRecord>;
    /**
     * Update the record to a new state and emit an state changed event. Also updates the record
     * in storage.
     *
     * @param credentialRecord The credential record to update the state for
     * @param newState The state to update to
     *
     */
    updateState(agentContext: AgentContext, credentialRecord: CredentialExchangeRecord, newState: CredentialState): Promise<void>;
    protected emitStateChangedEvent(agentContext: AgentContext, credentialRecord: CredentialExchangeRecord, previousState: CredentialState | null): void;
    /**
     * Retrieve a credential record by id
     *
     * @param credentialRecordId The credential record id
     * @throws {RecordNotFoundError} If no record is found
     * @return The credential record
     *
     */
    getById(agentContext: AgentContext, credentialRecordId: string): Promise<CredentialExchangeRecord>;
    /**
     * Retrieve all credential records
     *
     * @returns List containing all credential records
     */
    getAll(agentContext: AgentContext): Promise<CredentialExchangeRecord[]>;
    findAllByQuery(agentContext: AgentContext, query: Query<CredentialExchangeRecord>): Promise<CredentialExchangeRecord[]>;
    /**
     * Find a credential record by id
     *
     * @param credentialRecordId the credential record id
     * @returns The credential record or null if not found
     */
    findById(agentContext: AgentContext, connectionId: string): Promise<CredentialExchangeRecord | null>;
    delete(agentContext: AgentContext, credentialRecord: CredentialExchangeRecord, options?: DeleteCredentialOptions): Promise<void>;
    /**
     * Retrieve a credential record by connection id and thread id
     *
     * @param connectionId The connection id
     * @param threadId The thread id
     * @throws {RecordNotFoundError} If no record is found
     * @throws {RecordDuplicateError} If multiple records are found
     * @returns The credential record
     */
    getByThreadAndConnectionId(agentContext: AgentContext, threadId: string, connectionId?: string): Promise<CredentialExchangeRecord>;
    /**
     * Find a credential record by connection id and thread id, returns null if not found
     *
     * @param connectionId The connection id
     * @param threadId The thread id
     * @returns The credential record
     */
    findByThreadAndConnectionId(agentContext: AgentContext, threadId: string, connectionId?: string): Promise<CredentialExchangeRecord | null>;
    update(agentContext: AgentContext, credentialRecord: CredentialExchangeRecord): Promise<void>;
}
